@@ -1,5 +1,5 @@
 generate_acq_codomain = function(surrogate, id, direction = "same") {
-  assert_r6(surrogate$archive, classes = "Archive")
+  assert_multi_class(surrogate$archive, c("Archive", "ArchiveAsync"))
   assert_string(id)
   assert_choice(direction, choices = c("same", "minimize", "maximize"))
   if (direction == "same") {
@@ -15,7 +15,7 @@ generate_acq_codomain = function(surrogate, id, direction = "same") {
 }
 
 generate_acq_domain = function(surrogate) {
-  assert_r6(surrogate$archive, classes = "Archive")
+  assert_archive(surrogate$archive)
   if ("set_id" %in% names(ps())) {
     # old paradox
     domain = surrogate$archive$search_space$clone(deep = TRUE)$subset(surrogate$cols_x)
